from setuptools import setup

setup(
    name="SetupPyUTF8",
    author="Saúl Ibarra Corretgé",
)
